@@ -485,6 +485,7 @@ def construct_dagster_k8s_job(
     user_defined_k8s_config=None,
     pod_name=None,
     component=None,
+    labels=None,
     env_vars=None,
 ):
     """Constructs a Kubernetes Job object for a dagster-graphql invocation.
@@ -499,6 +500,8 @@ def construct_dagster_k8s_job(
             in length. Defaults to "<job_name>-pod".
         component (str, optional): The name of the component, used to provide the Job label
             app.kubernetes.io/component. Defaults to None.
+        labels(Dict[str, str]): Additional labels to be attached to k8s jobs and pod templates.
+            Long label values are may be truncated.
         env_vars(Dict[str, str]): Additional environment variables to add to the K8s Container.
 
     Returns:
@@ -517,6 +520,7 @@ def construct_dagster_k8s_job(
     pod_name = check.opt_str_param(pod_name, "pod_name", default=job_name + "-pod")
     check.opt_str_param(component, "component")
     check.opt_dict_param(env_vars, "env_vars", key_type=str, value_type=str)
+    check.opt_dict_param(labels, "labels", key_type=str, value_type=str)
 
     check.invariant(
         len(job_name) <= MAX_K8S_NAME_LEN,
@@ -531,7 +535,7 @@ def construct_dagster_k8s_job(
     )
 
     # See: https://kubernetes.io/docs/concepts/overview/working-with-objects/common-labels/
-    dagster_labels = {
+    k8s_common_labels = {
         "app.kubernetes.io/name": "dagster",
         "app.kubernetes.io/instance": "dagster",
         "app.kubernetes.io/version": dagster_version,
@@ -539,7 +543,15 @@ def construct_dagster_k8s_job(
     }
 
     if component:
-        dagster_labels["app.kubernetes.io/component"] = component
+        k8s_common_labels["app.kubernetes.io/component"] = component
+
+    additional_labels = {
+        # Truncate too long label values to fit into 63-characters limit.
+        # https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#syntax-and-character-set
+        k: v[:63]
+        for k, v in (labels or {}).items()
+    }
+    dagster_labels = merge_dicts(k8s_common_labels, additional_labels)
 
     env = [kubernetes.client.V1EnvVar(name="DAGSTER_HOME", value=job_config.dagster_home)]
     if job_config.postgres_password_secret:
