@@ -1,9 +1,9 @@
 # start_marker
-from dagster import ModeDefinition, default_executors, pipeline
+from dagster import job
 from dagster_k8s import k8s_job_executor
 
 
-@pipeline(mode_defs=[ModeDefinition(executor_defs=default_executors + [k8s_job_executor])])
+@job(executor_def=k8s_job_executor)
 def k8s_pipeline():
     pass
 
